@@ -33,7 +33,7 @@ compiled.RxODE.md5 <- RxODE::rxMd5()
   ## nocov start
   ## Setup RxODE.prefer.tbl
   if (compiled.RxODE.md5 != RxODE::rxMd5()) {
-    stop("nlmixr compiled against different version of RxODE, cannot run nlmixr", call.=FALSE)
+    stop("nlmixr compiled against different version of RxODE, cannot run nlmixr\ntry `install.packages(\"nlmixr\", type = \"source\")` to recompile", call.=FALSE)
   }
   ## nlmixrSetupMemoize()
   ## options(keep.source = TRUE)
@@ -675,6 +675,8 @@ saemControl <- function(seed = 99,
                         powRange = 10,
                         lambdaRange = 3,
                         loadSymengine=FALSE,
+                        odeRecalcFactor=10^(0.5),
+                        maxOdeRecalc=5L,
                         ...) {
   type <- match.arg(type)
   .xtra <- list(...)
@@ -724,6 +726,8 @@ saemControl <- function(seed = 99,
     powRange = powRange,
     lambdaRange = lambdaRange,
     loadSymengine=loadSymengine,
+    odeRecalcFactor=odeRecalcFactor,
+    maxOdeRecalc=maxOdeRecalc,
     ...
   )
   if (length(.rm) > 0) {
